@@ -12,11 +12,6 @@ static TABLE_COMPARE_FUNC(compare_view)
     return *(uint64_t *) key_a == *(uint64_t *) key_b;
 }
 
-bool space_manager_has_separate_spaces(void)
-{
-    return SLSGetSpaceManagementMode(g_connection) == 1;
-}
-
 bool space_manager_query_space(FILE *rsp, uint64_t sid)
 {
     struct view *view = space_manager_query_view(&g_space_manager, sid);
@@ -958,7 +953,7 @@ void space_manager_handle_display_add(struct space_manager *sm, uint32_t did)
     sm->last_space_id = sm->current_space_id;
 }
 
-void space_manager_init(struct space_manager *sm)
+void space_manager_begin(struct space_manager *sm)
 {
     sm->layout = VIEW_FLOAT;
     sm->split_ratio = 0.5f;
@@ -967,7 +962,6 @@ void space_manager_init(struct space_manager *sm)
     sm->window_placement = CHILD_SECOND;
     sm->window_zoom_persist = true;
     sm->labels = NULL;
-
     table_init(&sm->view, 23, hash_view, compare_view);
 
     int display_count;
@@ -984,10 +978,7 @@ void space_manager_init(struct space_manager *sm)
             table_add(&sm->view, &space_list[j], view);
         }
     }
-}
 
-void space_manager_begin(struct space_manager *sm)
-{
     sm->current_space_id = space_manager_active_space();
     sm->last_space_id = sm->current_space_id;
     sm->did_begin = true;
