@@ -32,36 +32,57 @@ struct window
 {
     struct application *application;
     AXUIElementRef ref;
-    int connection;
     uint32_t id;
-    uint32_t **volatile id_ptr;
+    uint32_t *volatile id_ptr;
+    CGRect frame;
     uint8_t notification;
-    bool has_shadow;
-    bool is_fullscreen;
-    bool is_minimized;
-    bool is_floating;
-    bool is_sticky;
+    uint8_t rule_flags;
+    uint8_t flags;
     float opacity;
-    bool rule_manage;
-    bool rule_fullscreen;
-    bool rule_mff;
-    bool enable_mff;
     struct border border;
 };
 
+enum window_flag
+{
+    WINDOW_SHADOW     = 1 << 0,
+    WINDOW_FULLSCREEN = 1 << 1,
+    WINDOW_MINIMIZE   = 1 << 2,
+    WINDOW_FLOAT      = 1 << 3,
+    WINDOW_STICKY     = 1 << 4,
+};
+
+#define window_check_flag(w, x) ((w)->flags  &  (x))
+#define window_clear_flag(w, x) ((w)->flags &= ~(x))
+#define window_set_flag(w, x)   ((w)->flags |=  (x))
+
+enum window_rule_flag
+{
+    WINDOW_RULE_MANAGED    = 1 << 0,
+    WINDOW_RULE_FULLSCREEN = 1 << 1,
+    WINDOW_RULE_MFF        = 1 << 2,
+    WINDOW_RULE_MFF_VALUE  = 1 << 3,
+    WINDOW_RULE_BORDER     = 1 << 4,
+};
+
+#define window_rule_check_flag(w, x) ((w)->rule_flags  &  (x))
+#define window_rule_clear_flag(w, x) ((w)->rule_flags &= ~(x))
+#define window_rule_set_flag(w, x)   ((w)->rule_flags |=  (x))
+
 CFStringRef window_display_uuid(struct window *window);
-int window_display_id(struct window *window);
+uint32_t window_display_id(struct window *window);
 uint64_t window_space(struct window *window);
 uint64_t *window_space_list(struct window *window, int *count);
 void window_serialize(FILE *rsp, struct window *window);
-char *window_title(struct window *window);
+char *window_title_ts(struct window *window);
+CGPoint window_ax_origin(struct window *window);
 CGRect window_ax_frame(struct window *window);
-CGRect window_frame(struct window *window);
 float window_opacity(struct window *window);
 int window_level(struct window *window);
 uint64_t window_tags(struct window *window);
 CFStringRef window_role(struct window *window);
+char *window_role_ts(struct window *window);
 CFStringRef window_subrole(struct window *window);
+char *window_subrole_ts(struct window *window);
 bool window_can_move(struct window *window);
 bool window_can_resize(struct window *window);
 bool window_can_minimize(struct window *window);
